@@ -119,13 +119,14 @@ class PlateYaml(object):
 
 class PlateYamlSelector(object):
     def __init__(self, yaml_dir, revision_file="", default_country_order=None, legacy_in_default_country_order=False,
-                 always_add_other_country_to_plate_for_matching=True):
+                 always_add_other_country_to_plate_for_matching=True, priority_schemes=()):
         if default_country_order is None:
             default_country_order = []
         self.yaml_dir = yaml_dir
         self.default_country_order = default_country_order
         self.legacy_in_default_country_order = legacy_in_default_country_order
         self.always_add_other_country_to_plate_for_matching = always_add_other_country_to_plate_for_matching
+        self.priority_schemes = [{"code": scheme, "confidence": 1.0} for scheme in priority_schemes]
         self.schemes = {}
         self.revision_file = revision_file
         self.revision = ""
@@ -233,7 +234,7 @@ class PlateYamlSelector(object):
         """
         if alternatives is None:
             alternatives = []
-        country = [{"code": country, "confidence": country_confidence}]
+        country = self.priority_schemes + [{"code": country, "confidence": country_confidence}]
         if self.always_add_other_country_to_plate_for_matching and country != "OTHER":
             country.append({"code": "OTHER", "confidence": 0.5})
         return {
